@@ -21,7 +21,6 @@ from fireworks.utilities.fw_serializers import FWSerializable
 from fireworks.core.firework import FireWork, Launch, Workflow, FWAction, \
     Tracker
 from fireworks.utilities.fw_utilities import get_fw_logger
-from fireworks.utilities.timing import get_fw_timer
 
 
 __author__ = 'Anubhav Jain'
@@ -34,9 +33,6 @@ __date__ = 'Jan 30, 2013'
 
 # TODO: lots of duplication reduction and cleanup possible
 
-m_timer = get_fw_timer("LaunchPad")
-
-
 class WFLock(object):
     """
     Lock a Workflow, i.e. for performing update operations
@@ -225,7 +221,6 @@ class LaunchPad(FWSerializable):
 
         :param wf: a Workflow object.
         """
-        m_timer.start("add_wf")
         if isinstance(wf, FireWork):
             wf = Workflow.from_FireWork(wf)
 
@@ -243,7 +238,6 @@ class LaunchPad(FWSerializable):
         # insert the WFLinks
         self.workflows.insert(wf.to_db_dict())
 
-        m_timer.stop("add_wf")
         self.m_logger.info('Added a workflow. id_map: {}'.format(old_new))
         return old_new
 
@@ -288,6 +282,8 @@ class LaunchPad(FWSerializable):
         """
 
         links_dict = self.workflows.find_one({'nodes': fw_id})
+        if not links_dict:
+            raise ValueError("Could not find a Workflow with fw_id: {}".format(fw_id))
         fws = map(self.get_fw_by_id, links_dict["nodes"])
         return Workflow(fws, links_dict['links'], links_dict['name'],
                         links_dict['metadata'])
@@ -456,12 +452,18 @@ class LaunchPad(FWSerializable):
             except:
                 self.m_logger.debug('Database compaction failed (not critical)')
 
-    def defuse_fw(self, fw_id):
+    def defuse_fw(self, fw_id, rerun_duplicates=True):
         allowed_states = ['DEFUSED', 'WAITING', 'READY', 'FIZZLED']
         f = self.fireworks.find_and_modify(
             {'fw_id': fw_id, 'state': {'$in': allowed_states}},
             {'$set': {'state': 'DEFUSED'}})
 
+        if not f:
+            self.rerun_fw(fw_id, rerun_duplicates)
+            f = self.fireworks.find_and_modify(
+            {'fw_id': fw_id, 'state': {'$in': allowed_states}},
+            {'$set': {'state': 'DEFUSED'}})
+
         self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
         return f
 
@@ -827,8 +829,8 @@ class LaunchPad(FWSerializable):
 
         # rerun this FW
         m_fw = self.fireworks.find_one({"fw_id": fw_id}, {"state": 1})
-        if m_fw['state'] == 'ARCHIVED':
-            self.m_logger.info("Cannot rerun fw_id: {}: it is ARCHIVED.".format(fw_id))
+        if m_fw['state'] in ['ARCHIVED', 'DEFUSED'] :
+            self.m_logger.info("Cannot rerun fw_id: {}: it is {}.".format(fw_id, m_fw['state']))
         elif m_fw['state'] == 'WAITING':
             self.m_logger.debug("Skipping rerun fw_id: {}: it is already WAITING.".format(fw_id))
         else:
