@@ -167,7 +167,7 @@ class Rocket():
 
             # execute the FireTasks!
             for t in m_fw.tasks:
-                lp.log_message(logging.INFO, "Running task %s." % str(t))
+                lp.log_message(logging.INFO, "Task started: %s." % t.fw_name)
                 m_action = t.run_task(my_spec)
 
                 # read in a FWAction from a file, in case the task is not Python and cannot return it explicitly
@@ -188,7 +188,7 @@ class Rocket():
                 my_spec.update(m_action.update_spec)
                 for mod in m_action.mod_spec:
                     apply_mod(mod, my_spec)
-                lp.log_message(logging.INFO, "Task %s completed." % str(t))
+                lp.log_message(logging.INFO, "Task completed: %s " % t.fw_name)
                 if m_action.skip_remaining_tasks:
                     break
 
@@ -228,6 +228,7 @@ class Rocket():
 
         except:
             stop_backgrounds(ping_stop, btask_stops)
+            do_ping(lp, launch_id)  # one last ping, esp if there is a monitor
             traceback.print_exc()
             try:
                 m_action = FWAction(stored_data={'_message': 'runtime error during task', '_task': t.to_dict(),
